package com.huatek.busi.service;

import com.huatek.busi.entity.ParameterMake;
import com.huatek.busi.vo.ParameterMakeVo;
import com.huatek.busi.vo.ParameterResultVo;

import java.util.List;


public interface ParameterMakeService {

    /**
     * 变压器值比较
     * @return
     */
    List<ParameterResultVo> findTransformerParameterMake();




    /**
     * 各个报告Gis打标值
     * @return
     */
    List<ParameterMake> findGisParameterValue();

    /**
     * 从缓存读取增长、偏差率
     * @param refId
     * @return
     */
    List<ParameterResultVo> findTransformerParameterRate(String refId);

    /**
     * Gis值比较
     * @return
     */
    List<ParameterResultVo> findGisParameterMake();

    /**
     * 变压器打标字段相对、绝对增长率计算并插入缓存表
     *
     * @return
     */
    List<ParameterMakeVo> insertTransformerParameterMake();


    /**
     * Gis打标字段相对、绝对增长率计算并插入缓存表
     * @return
     */
    List<ParameterMakeVo> insertGisParameterMake();

    /**
     * 避雷器打标字段相对、绝对增长率计算并插入缓存表
     * @return
     */
    List<ParameterMakeVo> insertArresterParameterMake();

    /**
     * /开关柜打标字段相对、绝对增长率计算并插入缓存表
     * @return
     */
    List<ParameterMakeVo> insertSwitchgearParameterMake();

    /**
     * 电缆打标字段相对、绝对增长率计算并插入缓存表破
     * @return
     */
    List<ParameterMakeVo> insertCableParameterMake();

    List<ParameterMakeVo> insertGeneratorParameterMake();
}
